@@ -1,4 +1,4 @@
-#ident "$Id: fax_lib.h,v 4.9 1999/03/13 19:21:43 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: fax_lib.h,v 4.14 2006/02/09 14:51:20 gert Exp $ Copyright (c) Gert Doering"
 
 
 /* fax_lib.h
@@ -22,7 +22,7 @@ extern Modem_type modem_type;
 typedef enum { pp_mps, pp_eom, pp_eop,
 	       pp_pri_mps, pp_pri_eom, pp_pri_eop } Post_page_messages;
 
-extern unsigned char fax_send_swaptable[];
+extern unsigned char fax_send_swaptable[], fax_recv_swaptable[];
 
 /* function prototypes */
 
@@ -31,6 +31,7 @@ int fax_send _PROTO(( char * s, int fd ));	/* write to fd, with logging */
 int fax_wait_for _PROTO(( char * s, int fd ));
 int fax_command _PROTO(( char * send, char * expect, int fd ));
 
+void fax_find_directory _PROTO(( char * dirlist, char * directory, int size ));
 int fax_get_pages _PROTO(( int fd, int * pagenum, char * directory,
 			   int uid, int gid, int mode ));
 int fax_get_page_data _PROTO(( int modem_fd, int pagenum, char * directory,
@@ -52,6 +53,15 @@ Modem_type fax_get_modem_type _PROTO(( int fd, char * mclass ));
 
 typedef	struct	{ short vr, br, wd, ln, df, ec, bf, st; } fax_param_t;
 
+#ifdef CLASS1
+/* prototypes for class 1 functions */
+int fax1_highlevel_receive _PROTO(( int fd, int * pagenum, char * dirlist,
+		                    int uid, int gid, int mode));
+int fax1_set_l_id _PROTO(( int fd, char * fax_id ));
+int fax1_set_fdcc _PROTO(( int fd, int fine, int max, int min ));
+extern boolean fax1_receive_have_connect;
+#endif
+
 extern	char	fax_remote_id[];		/* remote FAX id +FTSI */
 extern	char	fax_param[];			/* transm. parameters +FDCS */
 extern	char	fax_hangup;
@@ -102,3 +112,8 @@ extern	int	modem_quirks;			/* modem specials */
 #define MQ_NO_XON	0x08	/* do not wait for XON char when sending */
 #define MQ_USR_FMINSP	0x20	/* USR: +FCC=1,<max> sets MIN speed instead */
 #define MQ_SHOW_NSF	0x40	/* set AT+FNR=1,1,1,1 (with NSFs) */
+#define MQ_FPS_NOT_HEX	0x80	/* +FPS:<status>,<lc> reported as decimal */
+
+/* note: 0x100 and 0x200 currently used for teergrubing - faxrecp.c */
+
+#define MQ_C1_NO_V17	0x400	/* class1: don't use V.17, even if adv. */
