@@ -1,4 +1,4 @@
-#ident "$Id: faxlib.c,v 4.56 2004/01/09 22:52:58 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: faxlib.c,v 4.65 2006/01/01 17:09:09 gert Exp $ Copyright (c) Gert Doering"
 
 /* faxlib.c
  *
@@ -135,6 +135,37 @@ int  ix;
 	    }
 	}
 
+	else if ( strncmp( line, "+FDIS:", 6 ) == 0 ||
+	          strncmp( line, "+FIS:", 5 ) == 0 )
+	{
+	    short vr, br, wd, ln, df, ec, bf, st, jp=0;
+	    char msg[200];
+
+	    if ( sscanf( &line[ix], "%hd,%hx,%hd,%hd,%hd,%hd,%hd,%hd,%hd",
+			 &vr, &br, &wd, &ln, &df, &ec, &bf, &st, &jp ) < 8 )
+	    {
+		lprintf( L_WARN, "cannot evaluate +FIS-Code!" );
+	    }
+
+	    /* prettyprint "non-basic" receiver capabilities */
+            msg[0] = '\0';
+	    if ( vr & 1 ) strcat( msg, " fine" );
+	    if ( vr & 2 ) strcat( msg, " sfine/R8" );
+	    if ( vr & 4 ) strcat( msg, " sfine/R16" );
+	    if ( vr & 0x20 ) strcat( msg, " 400dpi" );
+	    if ( vr & 0x40 ) strcat( msg, " 300dpi" );
+
+	    if ( br > 3 ) strcat( msg, br <= 5? " 144": " V34" );
+	    if ( ln < 2 ) strcat( msg, ln == 0? " A4": " B4" );
+	    if ( df > 0 ) strcat( msg, df == 1? " 2D/MR":
+					 df == 2? " 2D/uncomp": " 2D/MMR" );
+	    if ( ec > 0 ) strcat( msg, " ECM" );
+	    if ( bf > 0 ) strcat( msg, " BFT" );
+	    if ( jp > 0 ) strcat( msg, " JPEG" );
+
+	    lprintf( L_MESG, "receiver cap.: '%s' ->%s", line, msg );
+	}
+
 	else if ( strncmp( line, "+FHNG:", 6 ) == 0 ||
 		  strncmp( line, "+FHS:", 5 ) == 0 )
 	{
@@ -282,8 +313,10 @@ void faxlib_init _P0( void )
 int fax_send _P2( (send, fd),
 		  char * send, int fd )
 {
-#ifdef FAX_COMMAND_DELAY
+#ifndef CLASS1
+# ifdef FAX_COMMAND_DELAY
     delay(FAX_COMMAND_DELAY);
+# endif
 #endif
 
     lprintf( L_MESG, "fax_send: '%s'", send );
@@ -321,7 +354,7 @@ int fax_set_l_id _P2( (fd, fax_id), int fd, char * fax_id )
     char flid[60];
 
 #ifdef CLASS1
-    if ( modem_type == Mt_class1 )
+    if ( modem_type == Mt_class1 || modem_type == Mt_class1_0 )
 		return fax1_set_l_id( fd, fax_id );
 #endif
 
@@ -345,14 +378,10 @@ int fax_set_fdcc _P4( (fd, fine, max, min),
     char buf[50];
 
 #ifdef CLASS1
-    if ( modem_type == Mt_class1 )
+    if ( modem_type == Mt_class1 || modem_type == Mt_class1_0 )
 		return fax1_set_fdcc( fd, fine, max, min );
 #endif
 
-#ifdef FAX_USRobotics			/* will go away...! */
-    modem_quirks |= MQ_USR_FMINSP;
-#endif
-
     if ( modem_quirks & MQ_USR_FMINSP )
     {
 	/* some early versions of the USR fax firmware got this wrong, (put 
@@ -417,6 +446,7 @@ int fax_set_flowcontrol _P2( (fd, hw_flow), int fd, int hw_flow )
  * for sending and receiving. Bah.)
  */
 unsigned char fax_send_swaptable[256];
+unsigned char fax_recv_swaptable[256];
 
 /* set up bit swap table */
 
@@ -441,14 +471,25 @@ int faxmodem_bit_order = 0;
 int fax_set_bor _P2( (fd, bor), int fd, int bor )
 {
     char buf[20];
-#ifdef CLASS1
-    if ( modem_type == Mt_class1 )
-		return fax1_set_bor( fd, bor );
-#endif
 
     faxmodem_bit_order = bor;
 
     fax_init_swaptable( faxmodem_bit_order & 1, fax_send_swaptable );
+
+    /* the whole bit swap table business is very ugly.  It comes from
+     * the way the old Rockwell class 2 code got it wrong (for reception
+     * only!), and the way mgetty and all tools have been adapted to that.
+     * So, class 2.x uses "1:1" (but uses different AT+FBO=x settings,
+     * depending on whether the modem will do it right), and class 1(.x) 
+     * has to use "reverse" tables for reception.  Bah.
+     */
+    if ( modem_type == Mt_class1 || modem_type == Mt_class1_0 )
+    {
+        fax_init_swaptable( FALSE, fax_recv_swaptable );	/* swap bits */
+	return NOERROR;
+    }
+
+    fax_init_swaptable( TRUE, fax_recv_swaptable );		/* no swap */
     
     if ( modem_type == Mt_class2_0 )
         sprintf( buf, "AT+FBO=%d", bor );
@@ -473,7 +514,8 @@ char *mc;
     if ( strcmp( mclass, "cls2" ) != 0 &&
 	 strcmp( mclass, "c2.0" ) != 0 &&
 	 strcmp( mclass, "auto1") != 0 &&
-	 strcmp( mclass, "cls1" ) != 0 )
+	 strcmp( mclass, "cls1" ) != 0 &&
+	 strcmp( mclass, "c1.0" ) != 0 )
     {
 	mclass = "auto";
     }
@@ -539,6 +581,13 @@ char *mc;
 	    return Mt_class1;
 	}
     }
+    if ( strcmp( mclass, "c1.0" ) == 0 )
+    {
+	if ( mdm_command( "AT+FCLASS=1.0", fd ) == SUCCESS )
+	{
+	    return Mt_class1_0;
+	}
+    }
 #endif
 
     /* not a 2.0 modem (or not allowed to check),
@@ -627,7 +676,8 @@ int mdm_identify _P1( (fd), int fd )
 	    break;
 	  case 1500:
 	  case 1501:
-	    lprintf( L_MESG, "ZyXEL Omni 56K (Plus) detected" );
+	  case 1507:
+	    lprintf( L_MESG, "ZyXEL Omni 56K (Plus/Pro) detected" );
 	    modem_type=Mt_class2_0;
 	    mis = mdm_get_idstring( "ATI1", 2, fd );
 	    break;
@@ -697,7 +747,7 @@ int mdm_identify _P1( (fd), int fd )
 	    modem_type=Mt_data;
 	    break;
 	  case 149: /* sure? */
-	    lprintf( L_MESG, "Intel 14.4E/400e detected (??)" );
+	    lprintf( L_MESG, "Intel 14.4E/400e detected (?)" );
 	    modem_type=Mt_unknown;
 	    break;
 	  case 247: /* use ATI2 for further distinction */
@@ -797,6 +847,11 @@ int mdm_identify _P1( (fd), int fd )
 	    else
 		modem_type=Mt_data;
 	}
+	else if ( strncmp( l, "Eicon ISDN Modem", 16 ) == 0 )
+	{
+	    lprintf( L_MESG, "Diehl/Eicon ISDN (assuming DIVA card with class 2 fax)" );
+	    modem_type=Mt_class2;
+	}
 	else if ( strncmp( l, "Linux ISDN", 10 ) == 0 )
 	{
 	    lprintf( L_MESG, "ISDN4Linux detected" );
@@ -852,6 +907,11 @@ int mdm_identify _P1( (fd), int fd )
 	    modem_type=Mt_class2_0;
 	    modem_quirks |= MQ_FPS_NOT_HEX;
 	}
+	else if ( strncmp( l, "SIEMENS", 7 ) == 0 )	/* gert */
+	{
+	    lprintf( L_MESG, "possibly Siemens GSM modem?  assuming class 2" );
+	    modem_type=Mt_class2;
+	}
     }
 
     if ( mis != NULL ) 
